@@ -75,7 +75,6 @@ DEFSYM(north_west, "north-west");
 DEFSYM(north, "north");
 DEFSYM(north_east, "north-east");
 DEFSYM(west, "west");
-DEFSYM(center, "center");
 DEFSYM(east, "east");
 DEFSYM(south_west, "south-west");
 DEFSYM(south, "south");
@@ -1845,7 +1844,6 @@ windows_init (void)
     rep_INTERN(north);
     rep_INTERN(north_east);
     rep_INTERN(west);
-    rep_INTERN(center);
     rep_INTERN(east);
     rep_INTERN(south_west);
     rep_INTERN(south);
